Learn R Programming

vivid (version 0.2.9)

vip2vivid: vip2vivid

Description

Takes measured importance and interactions from the vip package and turns them into a matrix which can be used for plotting. Accepts any of the variable importance methods supplied by vip.

Usage

vip2vivid(importance, interaction, reorder = TRUE)

Value

A matrix of interaction values, with importance on the diagonal.

Arguments

importance

Measured importance from the vip package using vi function.

interaction

Measured interaction from the vip package using vint function.

reorder

If TRUE (default) uses DendSer to reorder the matrix of interactions and variable importances.

Examples

Run this code
if (FALSE) {
library(ranger)
library(vip)
aq <- na.omit(airquality) # get data
nameAq <- names(aq[-1]) # get feature names

rF <- ranger(Ozone ~ ., data = aq, importance = "permutation") # create ranger random forest fit
vImp <- vi(rF) # vip importance
vInt <- vint(rF, feature_names = nameAq) # vip interaction

vip2vivid(vImp, vInt)
}

Run the code above in your browser using DataLab